@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010,2011,2014 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010,2011,2014,2016,2018,2019 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -45,7 +45,7 @@
 /**                # Version 5.1  : from : 09 nov 2008     **/
 /**                                 to   : 26 mar 2011     **/
 /**                # Version 6.0  : from : 07 nov 2011     **/
-/**                                 to   : 08 aug 2014     **/
+/**                                 to   : 31 aug 2019     **/
 /**                                                        **/
 /************************************************************/
 
@@ -146,11 +146,8 @@ const BgraphBipartBdParam * const paraptr)        /*+ Method parameters +*/
   queutailval  = 0;
   bndvlvlnum   = 0;                               /* Assume first layer is last layer   */
   while (distmax -- > 0) {                        /* For all passes except the last one */
-/*    Gnum                orgvertnum;*/
-/*    Gnum                orgdistval;*/
-
-    bndvlvlnum = queuheadval;                     /* Record start of last layer */
-    while (queutailval < bndvlvlnum) {            /* For all vertices in queue  */
+    bndvlvlnum = queuheadval;                     /* Record start of last layer         */
+    while (queutailval < bndvlvlnum) {            /* For all vertices in queue          */
       Gnum                orgvertnum;
       Gnum                orgedgenum;
       Gnum                orgpartval;
@@ -269,7 +266,9 @@ const BgraphBipartBdParam * const paraptr)        /*+ Method parameters +*/
   bndedlotax = bndgrafdat.s.edlotax;
   bndvnumtax = bndgrafdat.s.vnumtax;
 
-  for (bndvertnum = bndedgenum = orggrafptr->s.baseval, bnddegrmax = bndedlosum = bndcommgainextn = bndcommgainextn1 = 0;
+  bndvlvlnum += orggrafptr->s.baseval;            /* Now bndvlvlnum is based */
+  for (bndvertnum = bndedgenum = orggrafptr->s.baseval,
+       bnddegrmax = bndedlosum = bndcommgainextn = bndcommgainextn1 = 0;
        bndvertnum < bndvlvlnum; bndvertnum ++) {  /* Fill index array for vertices not belonging to last level */
     Gnum                orgvertnum;
     GraphPart           orgpartval;
@@ -382,11 +381,8 @@ const BgraphBipartBdParam * const paraptr)        /*+ Method parameters +*/
   }
 #endif /* SCOTCH_DEBUG_BGRAPH2 */
   bndgrafdat.s.edgenbr = bndedgetmp - orggrafptr->s.baseval;
-  bndgrafdat.s.verttax[bndvertnnd + 2] = bndedgetmp; /* Mark end of edge array with anchor vertices  */
-  for (bndvertnum = bndvlvlnum; bndvertnum < bndvertnnd; bndvertnum ++) { /* Fill anchor edge arrays */
-    /*Gnum                orgvertnum;*/
-
-    /*orgvertnum = bndvnumtax[bndvertnum];*/
+  bndgrafdat.s.verttax[bndvertnnd + 2] = bndedgetmp; /* Mark end of edge array with anchor vertices             */
+  for (bndvertnum = bndvlvlnum; bndvertnum < bndvertnnd; bndvertnum ++) { /* Fill anchor edge arrays            */
     if (bndgrafdat.s.verttax[bndvertnum + 1] > bndgrafdat.s.verttax[bndvertnum]) { /* If vertex is not isolated */
       Gnum                bndedgelst;             /* Number of last edge */
       Gnum                bndvertend;
@@ -445,9 +441,7 @@ const BgraphBipartBdParam * const paraptr)        /*+ Method parameters +*/
     Gnum                bndfronnnd;
     Gnum                bndvertnum;
     Gnum                bndedgenum;
-    Gnum                bndedloval;
 
-    bndedloval      = 1;                          /* Assume unity edge weights */
     bndcommloadintn = 0;
     for (bndvertnum = orggrafptr->s.baseval, bndfronnnd = bndvertnum + orggrafptr->fronnbr; /* Compute communication load at frontier */
          bndvertnum < bndfronnnd; bndvertnum ++) {
@@ -461,8 +455,7 @@ const BgraphBipartBdParam * const paraptr)        /*+ Method parameters +*/
         Gnum                bndpartend;
 
         bndpartend = (Gnum) bndgrafdat.parttax[bndedgetax[bndedgenum]];
-        bndedloval = bndedlotax[bndedgenum];
-        bndcommloadintn += bndedloval * bndpartend;
+        bndcommloadintn += bndedlotax[bndedgenum] * bndpartend;
       }
     }
 
